@@ -1,18 +1,20 @@
 #!/usr/bin/env python
 
 """
-$Id: unescaper.py 3245 2011-02-06 22:32:44Z inquisb $
-
-Copyright (c) 2006-2010 sqlmap developers (http://sqlmap.sourceforge.net/)
+Copyright (c) 2006-2014 sqlmap developers (http://sqlmap.org/)
 See the file 'doc/COPYING' for copying permission
 """
 
 from lib.core.common import Backend
-from lib.core.datatype import advancedDict
+from lib.core.data import conf
+from lib.core.datatype import AttribDict
 from lib.core.settings import EXCLUDE_UNESCAPE
 
-class Unescaper(advancedDict):
-    def unescape(self, expression, quote=True, dbms=None):
+class Unescaper(AttribDict):
+    def escape(self, expression, quote=True, dbms=None):
+        if conf.noEscape:
+            return expression
+
         if expression is None:
             return expression
 
