@@ -1,14 +1,10 @@
 #!/usr/bin/env python
 
 """
-$Id: templates.py 3147 2011-01-31 11:41:28Z stamparm $
-
-Copyright (c) 2006-2010 sqlmap developers (http://sqlmap.sourceforge.net/)
+Copyright (c) 2006-2014 sqlmap developers (http://sqlmap.org/)
 See the file 'doc/COPYING' for copying permission
 """
 
-import lib.core.common
-
 from lib.core.data import kb
 from lib.request.connect import Connect as Request
 
@@ -17,11 +13,10 @@ def getPageTemplate(payload, place):
 
     if payload and place:
         if (payload, place) not in kb.pageTemplates:
-            page, _ = Request.queryPage(payload, place, content=True)
+            page, _ = Request.queryPage(payload, place, content=True, raise404=False)
             kb.pageTemplates[(payload, place)] = (page, kb.lastParserStatus is None)
 
         retVal = kb.pageTemplates[(payload, place)]
 
     return retVal
 
-lib.core.common.getPageTemplate = getPageTemplate
