@@ -1,15 +1,14 @@
 #!/usr/bin/env python
 
 """
-$Id: timeout.py 2299 2010-11-07 22:34:29Z inquisb $
-
-Copyright (c) 2006-2010 sqlmap developers (http://sqlmap.sourceforge.net/)
+Copyright (c) 2006-2014 sqlmap developers (http://sqlmap.org/)
 See the file 'doc/COPYING' for copying permission
 """
 
 import threading
 
 from lib.core.data import logger
+from lib.core.enums import CUSTOM_LOGGING
 
 def timeout(func, args=(), kwargs={}, duration=1, default=None):
     class InterruptableThread(threading.Thread):
@@ -21,7 +20,7 @@ def timeout(func, args=(), kwargs={}, duration=1, default=None):
             try:
                 self.result = func(*args, **kwargs)
             except Exception, msg:
-                logger.log(7, msg)
+                logger.log(CUSTOM_LOGGING.TRAFFIC_IN, msg)
                 self.result = default
 
     thread = InterruptableThread()
