@@ -1,9 +1,7 @@
 #!/usr/bin/env python
 
 """
-$Id: enumeration.py 3100 2011-01-24 17:51:56Z stamparm $
-
-Copyright (c) 2006-2010 sqlmap developers (http://sqlmap.sourceforge.net/)
+Copyright (c) 2006-2014 sqlmap developers (http://sqlmap.org/)
 See the file 'doc/COPYING' for copying permission
 """
 
@@ -15,7 +13,7 @@ class Enumeration(GenericEnumeration):
         GenericEnumeration.__init__(self)
 
     def getDbs(self):
-        warnMsg = "on Firebird it is not possible to enumerate databases"
+        warnMsg = "on Firebird it is not possible to enumerate databases (use only '--tables')"
         logger.warn(warnMsg)
 
         return []
@@ -32,14 +30,12 @@ class Enumeration(GenericEnumeration):
 
         return []
 
-    def searchTable(self):
-        warnMsg = "on Firebird searching of tables is not implemented"
-        logger.warn(warnMsg)
-
-        return []
-
     def searchColumn(self):
-        warnMsg = "on Firebird searching of columns is not implemented"
+        warnMsg = "on Firebird it is not possible to search columns"
         logger.warn(warnMsg)
 
         return []
+
+    def getHostname(self):
+        warnMsg = "on Firebird it is not possible to enumerate the hostname"
+        logger.warn(warnMsg)
