@@ -1,16 +1,13 @@
 #!/usr/bin/env python
 
 """
-$Id: __init__.py 2629 2010-12-09 17:10:22Z stamparm $
-
-Copyright (c) 2006-2010 sqlmap developers (http://sqlmap.sourceforge.net/)
+Copyright (c) 2006-2014 sqlmap developers (http://sqlmap.org/)
 See the file 'doc/COPYING' for copying permission
 """
 
 from lib.core.enums import DBMS
 from lib.core.settings import MAXDB_SYSTEM_DBS
 from lib.core.unescaper import unescaper
-
 from plugins.dbms.maxdb.enumeration import Enumeration
 from plugins.dbms.maxdb.filesystem import Filesystem
 from plugins.dbms.maxdb.fingerprint import Fingerprint
@@ -33,4 +30,4 @@ class MaxDBMap(Syntax, Fingerprint, Enumeration, Filesystem, Miscellaneous, Take
         Miscellaneous.__init__(self)
         Takeover.__init__(self)
 
-    unescaper[DBMS.MAXDB] = Syntax.unescape
+    unescaper[DBMS.MAXDB] = Syntax.escape
