@@ -1,14 +1,11 @@
 #!/usr/bin/env python
 
 """
-$Id: connector.py 2177 2010-10-27 10:37:54Z inquisb $
-
-Copyright (c) 2006-2010 sqlmap developers (http://sqlmap.sourceforge.net/)
+Copyright (c) 2006-2014 sqlmap developers (http://sqlmap.org/)
 See the file 'doc/COPYING' for copying permission
 """
 
-from lib.core.exception import sqlmapUnsupportedFeatureException
-
+from lib.core.exception import SqlmapUnsupportedFeatureException
 from plugins.generic.connector import Connector as GenericConnector
 
 class Connector(GenericConnector):
@@ -16,6 +13,6 @@ class Connector(GenericConnector):
         GenericConnector.__init__(self)
 
     def connect(self):
-        errMsg  = "on SAP MaxDB it is not possible to establish a "
+        errMsg = "on SAP MaxDB it is not possible to establish a "
         errMsg += "direct connection"
-        raise sqlmapUnsupportedFeatureException, errMsg
+        raise SqlmapUnsupportedFeatureException(errMsg)
