@@ -1,16 +1,13 @@
 #!/usr/bin/env python
 
 """
-$Id: __init__.py 2629 2010-12-09 17:10:22Z stamparm $
-
-Copyright (c) 2006-2010 sqlmap developers (http://sqlmap.sourceforge.net/)
+Copyright (c) 2006-2014 sqlmap developers (http://sqlmap.org/)
 See the file 'doc/COPYING' for copying permission
 """
 
 from lib.core.enums import DBMS
 from lib.core.settings import MSSQL_SYSTEM_DBS
 from lib.core.unescaper import unescaper
-
 from plugins.dbms.mssqlserver.enumeration import Enumeration
 from plugins.dbms.mssqlserver.filesystem import Filesystem
 from plugins.dbms.mssqlserver.fingerprint import Fingerprint
@@ -34,4 +31,4 @@ class MSSQLServerMap(Syntax, Fingerprint, Enumeration, Filesystem, Miscellaneous
         Miscellaneous.__init__(self)
         Takeover.__init__(self)
 
-    unescaper[DBMS.MSSQL] = Syntax.unescape
+    unescaper[DBMS.MSSQL] = Syntax.escape
