@@ -1,16 +1,13 @@
 #!/usr/bin/env python
 
 """
-$Id: __init__.py 2629 2010-12-09 17:10:22Z stamparm $
-
-Copyright (c) 2006-2010 sqlmap developers (http://sqlmap.sourceforge.net/)
+Copyright (c) 2006-2014 sqlmap developers (http://sqlmap.org/)
 See the file 'doc/COPYING' for copying permission
 """
 
 from lib.core.enums import DBMS
 from lib.core.settings import MYSQL_SYSTEM_DBS
 from lib.core.unescaper import unescaper
-
 from plugins.dbms.mysql.enumeration import Enumeration
 from plugins.dbms.mysql.filesystem import Filesystem
 from plugins.dbms.mysql.fingerprint import Fingerprint
@@ -25,12 +22,12 @@ class MySQLMap(Syntax, Fingerprint, Enumeration, Filesystem, Miscellaneous, Take
 
     def __init__(self):
         self.excludeDbsList = MYSQL_SYSTEM_DBS
-        self.sysUdfs        = {
-                                # UDF name:    UDF return data-type
-                                "sys_exec":    { "return": "int" },
-                                "sys_eval":    { "return": "string" },
-                                "sys_bineval": { "return": "int" }
-                              }
+        self.sysUdfs = {
+                         # UDF name:    UDF return data-type
+                         "sys_exec":    { "return": "int" },
+                         "sys_eval":    { "return": "string" },
+                         "sys_bineval": { "return": "int" }
+                       }
 
         Syntax.__init__(self)
         Fingerprint.__init__(self)
@@ -39,4 +36,4 @@ class MySQLMap(Syntax, Fingerprint, Enumeration, Filesystem, Miscellaneous, Take
         Miscellaneous.__init__(self)
         Takeover.__init__(self)
 
-    unescaper[DBMS.MYSQL] = Syntax.unescape
+    unescaper[DBMS.MYSQL] = Syntax.escape
