@@ -1,16 +1,13 @@
 #!/usr/bin/env python
 
 """
-$Id: __init__.py 2629 2010-12-09 17:10:22Z stamparm $
-
-Copyright (c) 2006-2010 sqlmap developers (http://sqlmap.sourceforge.net/)
+Copyright (c) 2006-2014 sqlmap developers (http://sqlmap.org/)
 See the file 'doc/COPYING' for copying permission
 """
 
 from lib.core.enums import DBMS
 from lib.core.settings import ORACLE_SYSTEM_DBS
 from lib.core.unescaper import unescaper
-
 from plugins.dbms.oracle.enumeration import Enumeration
 from plugins.dbms.oracle.filesystem import Filesystem
 from plugins.dbms.oracle.fingerprint import Fingerprint
@@ -33,4 +30,4 @@ class OracleMap(Syntax, Fingerprint, Enumeration, Filesystem, Miscellaneous, Tak
         Miscellaneous.__init__(self)
         Takeover.__init__(self)
 
-    unescaper[DBMS.ORACLE] = Syntax.unescape
+    unescaper[DBMS.ORACLE] = Syntax.escape
