@@ -1,15 +1,18 @@
 #!/usr/bin/env python
 
 """
-$Id: enumeration.py 2963 2011-01-14 11:55:20Z inquisb $
-
-Copyright (c) 2006-2010 sqlmap developers (http://sqlmap.sourceforge.net/)
+Copyright (c) 2006-2014 sqlmap developers (http://sqlmap.org/)
 See the file 'doc/COPYING' for copying permission
 """
 
-from lib.core.enums import DBMS
+from lib.core.data import logger
+
 from plugins.generic.enumeration import Enumeration as GenericEnumeration
 
 class Enumeration(GenericEnumeration):
     def __init__(self):
         GenericEnumeration.__init__(self)
+
+    def getHostname(self):
+        warnMsg = "on PostgreSQL it is not possible to enumerate the hostname"
+        logger.warn(warnMsg)
