@@ -1,14 +1,11 @@
 #!/usr/bin/env python
 
 """
-$Id: filesystem.py 2009 2010-10-14 23:18:29Z stamparm $
-
-Copyright (c) 2006-2010 sqlmap developers (http://sqlmap.sourceforge.net/)
+Copyright (c) 2006-2014 sqlmap developers (http://sqlmap.org/)
 See the file 'doc/COPYING' for copying permission
 """
 
-from lib.core.exception import sqlmapUnsupportedFeatureException
-
+from lib.core.exception import SqlmapUnsupportedFeatureException
 from plugins.generic.filesystem import Filesystem as GenericFilesystem
 
 class Filesystem(GenericFilesystem):
@@ -17,8 +14,8 @@ class Filesystem(GenericFilesystem):
 
     def readFile(self, rFile):
         errMsg = "on Sybase it is not possible to read files"
-        raise sqlmapUnsupportedFeatureException, errMsg
+        raise SqlmapUnsupportedFeatureException(errMsg)
 
-    def writeFile(self, wFile, dFile, fileType=None, confirm=True):
+    def writeFile(self, wFile, dFile, fileType=None, forceCheck=False):
         errMsg = "on Sybase it is not possible to write files"
-        raise sqlmapUnsupportedFeatureException, errMsg
+        raise SqlmapUnsupportedFeatureException(errMsg)
