@@ -1,9 +1,7 @@
 #!/usr/bin/env python
 
 """
-$Id: space2comment.py 3555 2011-04-04 08:18:26Z stamparm $
-
-Copyright (c) 2006-2010 sqlmap developers (http://sqlmap.sourceforge.net/)
+Copyright (c) 2006-2014 sqlmap developers (http://sqlmap.org/)
 See the file 'doc/COPYING' for copying permission
 """
 
@@ -11,10 +9,24 @@ from lib.core.enums import PRIORITY
 
 __priority__ = PRIORITY.LOW
 
-def tamper(payload):
+def dependencies():
+    pass
+
+def tamper(payload, **kwargs):
     """
-    Replaces ' ' with '/**/'
-    Example: 'SELECT id FROM users' becomes 'SELECT/**/id/**/FROM/**/users'
+    Replaces space character (' ') with comments '/**/'
+
+    Tested against:
+        * Microsoft SQL Server 2005
+        * MySQL 4, 5.0 and 5.5
+        * Oracle 10g
+        * PostgreSQL 8.3, 8.4, 9.0
+
+    Notes:
+        * Useful to bypass weak and bespoke web application firewalls
+
+    >>> tamper('SELECT id FROM users')
+    'SELECT/**/id/**/FROM/**/users'
     """
 
     retVal = payload
@@ -36,11 +48,10 @@ def tamper(payload):
             elif payload[i] == '"':
                 doublequote = not doublequote
 
-            elif payload[i]==" " and not doublequote and not quote:
+            elif payload[i] == " " and not doublequote and not quote:
                 retVal += "/**/"
                 continue
 
             retVal += payload[i]
 
     return retVal
-
