@@ -1,9 +1,7 @@
 #!/usr/bin/env python
 
 """
-$Id: space2plus.py 3555 2011-04-04 08:18:26Z stamparm $
-
-Copyright (c) 2006-2010 sqlmap developers (http://sqlmap.sourceforge.net/)
+Copyright (c) 2006-2014 sqlmap developers (http://sqlmap.org/)
 See the file 'doc/COPYING' for copying permission
 """
 
@@ -11,10 +9,20 @@ from lib.core.enums import PRIORITY
 
 __priority__ = PRIORITY.LOW
 
-def tamper(payload):
+def dependencies():
+    pass
+
+def tamper(payload, **kwargs):
     """
-    Replaces ' ' with '+'
-    Example: 'SELECT id FROM users' becomes 'SELECT+id+FROM+users'
+    Replaces space character (' ') with plus ('+')
+
+    Notes:
+        * Is this any useful? The plus get's url-encoded by sqlmap engine
+          invalidating the query afterwards
+        * This tamper script works against all databases
+
+    >>> tamper('SELECT id FROM users')
+    'SELECT+id+FROM+users'
     """
 
     retVal = payload
@@ -36,7 +44,7 @@ def tamper(payload):
             elif payload[i] == '"':
                 doublequote = not doublequote
 
-            elif payload[i]==" " and not doublequote and not quote:
+            elif payload[i] == " " and not doublequote and not quote:
                 retVal += "+"
                 continue
 
