@@ -1,9 +1,7 @@
 #!/usr/bin/env python
 
 """
-$Id: space2randomblank.py 3555 2011-04-04 08:18:26Z stamparm $
-
-Copyright (c) 2006-2010 sqlmap developers (http://sqlmap.sourceforge.net/)
+Copyright (c) 2006-2014 sqlmap developers (http://sqlmap.org/)
 See the file 'doc/COPYING' for copying permission
 """
 
@@ -13,13 +11,34 @@ from lib.core.enums import PRIORITY
 
 __priority__ = PRIORITY.LOW
 
-def tamper(payload):
+def dependencies():
+    pass
+
+def tamper(payload, **kwargs):
     """
-    Replaces ' ' with a random blank char from a set ('\r', '\n', '\t')
-    Example: 'SELECT id FROM users' becomes 'SELECT\rid\tFROM\nusers'
+    Replaces space character (' ') with a random blank character from a
+    valid set of alternate characters
+
+    Tested against:
+        * Microsoft SQL Server 2005
+        * MySQL 4, 5.0 and 5.5
+        * Oracle 10g
+        * PostgreSQL 8.3, 8.4, 9.0
+
+    Notes:
+        * Useful to bypass several web application firewalls
+
+    >>> random.seed(0)
+    >>> tamper('SELECT id FROM users')
+    'SELECT%0Did%0DFROM%0Ausers'
     """
 
-    blanks = ['\r', '\n', '\t']
+    # ASCII table:
+    #   TAB     09      horizontal TAB
+    #   LF      0A      new line
+    #   FF      0C      new page
+    #   CR      0D      carriage return
+    blanks = ("%09", "%0A", "%0C", "%0D")
     retVal = payload
 
     if payload:
@@ -39,11 +58,10 @@ def tamper(payload):
             elif payload[i] == '"':
                 doublequote = not doublequote
 
-            elif payload[i]==" " and not doublequote and not quote:
+            elif payload[i] == ' ' and not doublequote and not quote:
                 retVal += random.choice(blanks)
                 continue
 
             retVal += payload[i]
 
     return retVal
-
